<?php
/**
 * This is the child theme for PressBook theme.
 *
 * (See https://developer.wordpress.org/themes/advanced-topics/child-themes/#how-to-create-a-child-theme)
 *
 * @package PressBook_Media
 */

defined( 'ABSPATH' ) || die();

define( 'PRESSBOOK_MEDIA_VERSION', '1.0.5' );

/**
 * Load child theme text domain.
 */
function pressbook_media_setup() {
	load_child_theme_textdomain( 'pressbook-media', get_stylesheet_directory() . '/languages' );
}
add_action( 'after_setup_theme', 'pressbook_media_setup', 11 );

/**
 * Load child theme services.
 *
 * @param  array $services Parent theme services.
 * @return array
 */
function pressbook_media_services( $services ) {
	require get_stylesheet_directory() . '/inc/classes/class-pressbook-media-helpers.php';
	require get_stylesheet_directory() . '/inc/classes/class-pressbook-media-cssrules.php';
	require get_stylesheet_directory() . '/inc/classes/class-pressbook-media-scripts.php';
	require get_stylesheet_directory() . '/inc/classes/class-pressbook-media-editor.php';
	require get_stylesheet_directory() . '/inc/classes/class-pressbook-media-topinfo.php';
	require get_stylesheet_directory() . '/inc/classes/class-pressbook-media-primarynavbar.php';
	require get_stylesheet_directory() . '/inc/classes/class-pressbook-media-related-posts.php';
	require get_stylesheet_directory() . '/inc/classes/class-pressbook-media-block-patterns.php';

	foreach ( $services as $key => $service ) {
		if ( 'PressBook\Editor' === $service ) {
			$services[ $key ] = PressBook_Media_Editor::class;
		} elseif ( 'PressBook\Scripts' === $service ) {
			$services[ $key ] = PressBook_Media_Scripts::class;
		}
	}

	array_push( $services, PressBook_Media_TopInfo::class );
	array_push( $services, PressBook_Media_PrimaryNavbar::class );
	array_push( $services, PressBook_Media_Related_Posts::class );
	array_push( $services, PressBook_Media_Block_Patterns::class );

	return $services;
}
add_filter( 'pressbook_services', 'pressbook_media_services' );

/**
 * Change default styles.
 *
 * @param  array $styles Default sttyles.
 * @return array
 */
function pressbook_media_default_styles( $styles ) {
	$styles['top_navbar_bg_color_1']         = '#094ae9';
	$styles['top_navbar_bg_color_2']         = '#386be9';
	$styles['top_info_bg_color']             = '#f3f3f3';
	$styles['top_info_color']                = '#515151';
	$styles['top_info_font_wgt']             = '600';
	$styles['top_info_button_bg_color']      = '#ffffff';
	$styles['top_info_button_border_color']  = '#a7a7a7';
	$styles['top_info_button_color']         = '#515151';
	$styles['primary_navbar_bg_color']       = '#1d2327';
	$styles['primary_navbar_hover_bg_color'] = '#a41e6d';
	$styles['button_bg_color_1']             = '#094ae9';
	$styles['button_bg_color_2']             = '#386be9';
	$styles['footer_bg_color']               = '#010e2d';
	$styles['footer_credit_link_color']      = '#a41e6d';

	return $styles;
}
add_filter( 'pressbook_default_styles', 'pressbook_media_default_styles' );

/**
 * Change welcome page title.
 *
 * @param  string $page_title Welcome page title.
 * @return string
 */
function pressbook_media_welcome_page_title( $page_title ) {
	return esc_html_x( 'PressBook Media', 'page title', 'pressbook-media' );
}
add_filter( 'pressbook_welcome_page_title', 'pressbook_media_welcome_page_title' );

/**
 * Change welcome menu title.
 *
 * @param  string $menu_title Welcome menu title.
 * @return string
 */
function pressbook_media_welcome_menu_title( $menu_title ) {
	return esc_html_x( 'PressBook Media', 'menu title', 'pressbook-media' );
}
add_filter( 'pressbook_welcome_menu_title', 'pressbook_media_welcome_menu_title' );

/**
 * Recommended plugins.
 */
require get_stylesheet_directory() . '/inc/recommended-plugins.php';
